emacs-devel
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

Facilitate Customisation of Message-Mode Header Completion Behaviour


From: Alexander Adolf
Subject: Facilitate Customisation of Message-Mode Header Completion Behaviour
Date: Wed, 09 Mar 2022 16:00:18 +0100

Hello,

I am moving from 3rd party completion frameworks to use
completion-at-point- only. In the process, I discovered that I want to
override message-expand-name, which is listed in
message-completion-alist. This patch adds a new defcustom for the email
header regular expression, so as to allow users (a) to customise the
regular expression, and (b) to use alist functions for manipulating
message-completion-alist, effectively making programmatic customisation
easier.

Cheers,

  --alexander

>From 54e6bcf64bdc8d6526071692d778bca3a453fb5f Mon Sep 17 00:00:00 2001
From: Alexander Adolf <alexander.adolf@condition-alpha.com>
Date: Wed, 9 Mar 2022 15:26:55 +0100
Subject: [PATCH] Facilitate Customisation of Message-Mode Header Completion
 Behaviour

This commit refactors the regular expression used for recognising
message headers containing email addresses into a new defcustom. This
brings it on par with the regular expression for recognising headers
containing newsgroup names. At the same time, the regular expression
for email address headers is extended to match additional headers.

For one, this allows users to customise the regular expression for
email headers, which was not possible before. On the other hand it
facilitates customising the value of message-completion-alist, since
having the regular expression (which is the car of the conses in
message-completion-alist) in a variable makes changing the function to
be called (which is the cdr of the conses in message-completion-alist)
easier.
---
 lisp/gnus/message.el | 12 +++++++++---
 1 file changed, 9 insertions(+), 3 deletions(-)

diff --git a/lisp/gnus/message.el b/lisp/gnus/message.el
index a5b3d40467..fd2176a10f 100644
--- a/lisp/gnus/message.el
+++ b/lisp/gnus/message.el
@@ -8265,17 +8265,23 @@ When FORCE, rebuild the tool bar."
                                    'message-mode-map))))
   message-tool-bar-map)
 
 ;;; Group name completion.
 
 (defcustom message-newgroups-header-regexp
   "^\\(Newsgroups\\|Followup-To\\|Posted-To\\|Gcc\\):"
-  "Regexp that match headers that lists groups."
+  "Regexp matching headers that list groups."
+  :group 'message
+  :type 'regexp)
+
+(defcustom message-email-recipient-header-regexp
+  "^\\([^ 
:]*-\\)?\\(To\\|B?Cc\\|From\\|Reply-to\\|Mail-Followup-To\\|Mail-Copies-To\\):.*?
 *\\([^,;]*\\)"
+  "Regexp matching headers that list email addresses."
   :group 'message
   :type 'regexp)
 
 (defcustom message-completion-alist
   `((,message-newgroups-header-regexp . ,#'message-expand-group)
-    ("^\\([^ :]*-\\)?\\(To\\|B?Cc\\|From\\):" . ,#'message-expand-name))
+    (,message-email-recipient-header-regexp . ,#'message-expand-name))
   "Alist of (RE . FUN).  Use FUN for completion on header lines matching RE.
 FUN should be a function that obeys the same rules as those
 of `completion-at-point-functions'."
@@ -8265,17 +8265,23 @@ When FORCE, rebuild the tool bar."
   message-tool-bar-map)
 
-;;; Group name completion.
+;;; Group name and email address completion.
 
 (defcustom message-newgroups-header-regexp
-- 
2.35.1


reply via email to

[Prev in Thread] Current Thread [Next in Thread]